
#if !defined(NDEBUG)
#define _CRTDBG_MAP_ALLOC
#include <crtdbg.h>
#endif

#include <SAPS/SupportLib.h>
#include <windows.h>


PluginBase::PluginBase(ItfHost *host, wchar_t const *name,
    wchar_t const *author, wchar_t const *icon, unsigned int msvcver)
{
  StructSize = sizeof(PluginInfo);
  Name = name;
  Copyright = author;
  SupportInfo = L"";
  Icon = icon;
  SAPSVersion = ::Version();
  PluginVersion = 0;
  if (msvcver != _MSC_FULL_VER)
  {
    ::OutputDebugString(L"PluginBase: library version does not match MSVC version used. Please re-compile.\r\n");
    ::DebugBreak(); //  This will cause an exception if it escapes out into the wild, 
                    //  which is A-OK by me.
  }
}

void PluginBase::AddEffect(EffectInfoBase *b)
{
  effects_.push_back(b);
}

void PluginBase::Unload()
{
  //  todo: should I keep track of instance counts?
  delete this;
}

PluginInfo const *PluginBase::Info()
{
  return this;
}

size32 PluginBase::CountEffects()
{
  return effects_.size();
}

EffectInfo const *PluginBase::Info(size32 index)
{
  if (index >= effects_.size())
    return 0;
  return effects_[index];
}

ItfEffect *PluginBase::MakeEffect(size32 index)
{
  if (index >= effects_.size())
    return 0;
  //  todo: should I keep track of instance counts?
  return effects_[index]->Instantiate(this);
}

void *PluginBase::Extension(wchar_t const *name)
{
  return 0;
}

